@@ -17,7 +17,7 @@
 # subject to the GNU General Public License and may only be used or replicated
 # with the express permission of Red Hat, Inc.
 #
-from pykickstart.version import FC3, F8
+from pykickstart.version import FC3, F8, F37
 from pykickstart.base import KickstartCommand
 from pykickstart.errors import KickstartParseError
 from pykickstart.options import KSOptionParser
@@ -143,3 +143,27 @@ class F18_RootPw(F8_RootPw):
 
         self.set_to_self(ns)
         return self
+
+class F37_RootPw(F18_RootPw):
+    removedKeywords = F18_RootPw.removedKeywords
+    removedAttrs = F18_RootPw.removedAttrs
+
+    def __init__(self, writePriority=0, *args, **kwargs):
+        F18_RootPw.__init__(self, writePriority, *args, **kwargs)
+        self.allow_ssh = kwargs.get("allow_ssh", False)
+
+    def _getArgsAsStr(self):
+        retval = F18_RootPw._getArgsAsStr(self)
+
+        if self.allow_ssh:
+            retval += " --allow-ssh"
+
+        return retval
+
+    def _getParser(self):
+        op = F18_RootPw._getParser(self)
+        op.add_argument("--allow-ssh", action="store_true", default=False,
+                        version=F37, help="""
+                        This will allow remote root logins via ssh using only
+                        the password. Only use as a last resort.""")
+        return op
