@@ -30,13 +30,7 @@ This module exports several important classes:
 
     KickstartParser - The kickstart file parser state machine.
 """
-
-from __future__ import print_function
-
-try:
-    from collections.abc import Iterator
-except ImportError:  # python2 compatibility
-    from collections import Iterator
+from collections.abc import Iterator
 
 import os
 import shlex
@@ -130,7 +124,7 @@ def preprocessFromString(s):
        run.  Returns the location of the complete kickstart file.
     """
     s = preprocessFromStringToString(s)
-    if s:
+    if s.strip():
         import tempfile
         (outF, outName) = tempfile.mkstemp(suffix="-ks.cfg")
 
@@ -147,7 +141,7 @@ def preprocessKickstart(f):
        run.  Returns the location of the complete kickstart file.
     """
     s = preprocessKickstartToString(f)
-    if s:
+    if s.strip():
         import tempfile
         (outF, outName) = tempfile.mkstemp(suffix="-ks.cfg")
 
