@@ -36,7 +36,8 @@ from pykickstart.constants import KS_SCRIPT_PRE, KS_SCRIPT_POST, KS_SCRIPT_TRACE
                                   KS_BROKEN_IGNORE, KS_BROKEN_REPORT
 from pykickstart.errors import KickstartParseError, KickstartDeprecationWarning
 from pykickstart.options import KSOptionParser
-from pykickstart.version import FC4, F7, F9, F18, F21, F22, F24, F32, F34, RHEL6, RHEL7
+from pykickstart.version import FC4, F7, F9, F18, F21, F22, F24, F32, F34, RHEL6, RHEL7, RHEL9, \
+    isRHEL
 from pykickstart.i18n import _
 
 class Section(object):
@@ -627,7 +628,7 @@ class PackageSection(Section):
 
         op.remove_argument("--ignoredeps", version=F9)
         op.remove_argument("--resolvedeps", version=F9)
-        op.add_argument("--instLangs", "--inst-langs", default=None, version=F9, help="""
+        op.add_argument("--instLangs", default=None, version=F9, help="""
                         Specify the list of languages that should be installed.
                         This is different from the package group level
                         selections, though. This option does not specify what
@@ -686,7 +687,7 @@ class PackageSection(Section):
         if self.version < F24:
             return op
 
-        op.add_argument("--excludeWeakdeps", "--exclude-weakdeps", dest="excludeWeakdeps",
+        op.add_argument("--excludeWeakdeps", dest="excludeWeakdeps",
                         action="store_true", default=False, version=F24,
                         help="""
                         Do not install packages from weak dependencies. These
@@ -697,6 +698,13 @@ class PackageSection(Section):
         if self.version < F32:
             return op
 
+        op.add_argument("--instLangs", "--inst-langs", dest="instLangs", default=None,
+                        version=F32, help="Added ``--inst-langs`` alias")
+
+        op.add_argument("--excludeWeakdeps", "--exclude-weakdeps", dest="excludeWeakdeps",
+                        action="store_true", default=False, version=F32,
+                        help="Added ``--exclude-weakdeps`` alias")
+
         op.add_argument("--ignorebroken", action="store_true", default=False, version=F32,
                         help="""
                         Ignore any packages, groups or modules with conflicting files.
@@ -709,6 +717,10 @@ class PackageSection(Section):
                         were skipped. Using this option may result in an unusable system.**
                         """)
 
+        if isRHEL(self.version):
+            # The --ignorebroken feature is not supported on RHEL.
+            op.remove_argument("--ignorebroken", version=RHEL9)
+
         return op
 
     def handleHeader(self, lineno, args):
@@ -774,16 +786,17 @@ class PackageSection(Section):
         if self.version < F32:
             return
 
-        if ns.ignorebroken:
+        if getattr(ns, "ignorebroken", False):
             self.handler.packages.handleBroken = KS_BROKEN_IGNORE
         else:
             self.handler.packages.handleBroken = KS_BROKEN_REPORT
 
-        for option, new_option in \
+        for arg in args:
+            for option, new_option in \
                 {"--instLangs": "--inst-langs", "--excludeWeakdeps": "--exclude-weakdeps"}.items():
-            if option in args:
-                warnings.warn(_("The %(option)s option on line %(lineno)s will be deprecated in "
-                                "future releases. Please modify your kickstart file to replace "
-                                "this option with its preferred alias %(new_option)s.")
-                              % {"option": option, "lineno": lineno, "new_option": new_option},
-                              KickstartDeprecationWarning)
+                if option in arg:
+                    warnings.warn(_("The %(option)s option on line %(lineno)s will be deprecated in "
+                                    "future releases. Please modify your kickstart file to replace "
+                                    "this option with its preferred alias %(new_option)s.")
+                                  % {"option": option, "lineno": lineno, "new_option": new_option},
+                                  KickstartDeprecationWarning)
